@@ -99,7 +99,7 @@ impl crate::ArrayOfTable {
             && position <= self.double_bracket_end().unwrap().range().start
     }
 
-    /// Returns an iterator over the subtables of this table.
+    /// Returns an iterator over the sub-tables of this table.
     ///
     /// ```toml
     /// [[foo]]  # <- This is a self array of table
@@ -111,7 +111,7 @@ impl crate::ArrayOfTable {
     /// [[foo.baz]]  # <- This is also a subtable
     /// key = true
     /// ```
-    pub fn subtables(&self) -> impl Iterator<Item = TableOrArrayOfTable> + '_ {
+    pub fn sub_tables(&self) -> impl Iterator<Item = TableOrArrayOfTable> + '_ {
         support::node::next_siblings_nodes(self)
             .skip(1)
             .take_while(|t: &TableOrArrayOfTable| {
@@ -126,7 +126,37 @@ impl crate::ArrayOfTable {
             })
     }
 
-    pub fn array_of_tables_keys(&self) -> impl Iterator<Item = AstChildren<crate::Key>> + '_ {
+    pub fn parent_table_or_array_of_table_keys(
+        &self,
+        toml_version: TomlVersion,
+    ) -> impl Iterator<Item = AstChildren<crate::Key>> + '_ {
+        support::node::prev_siblings_nodes(self)
+            .filter_map(|node: TableOrArrayOfTable| node.header().map(|header| header.keys()))
+            .take_while(move |keys| {
+                match (
+                    self.header().and_then(|header| header.keys().next()),
+                    keys.clone().next(),
+                ) {
+                    (Some(a), Some(b)) => match (
+                        a.try_to_raw_text(toml_version),
+                        b.try_to_raw_text(toml_version),
+                    ) {
+                        (Ok(a), Ok(b)) => a == b,
+                        _ => false,
+                    },
+                    _ => false,
+                }
+            })
+            .filter(|keys| {
+                self.header()
+                    .map(|header_keys| header_keys.keys().starts_with(keys))
+                    .unwrap_or_default()
+            })
+    }
+
+    pub fn parrent_array_of_tables_keys(
+        &self,
+    ) -> impl Iterator<Item = AstChildren<crate::Key>> + '_ {
         support::node::prev_siblings_nodes(self)
             .filter_map(|node: ArrayOfTable| node.header().map(|header| header.keys()))
             .take_while(move |keys| {
