@@ -9,8 +9,8 @@
 
 use crate::{
     ArrayBracketSpaceWidth, ArrayCommaSpaceWidth, DateTimeDelimiter, IndentStyle, IndentWidth,
-    InlineTableBraceSpaceWidth, InlineTableCommaSpaceWidth, KeyValueEqualSpaceWidth, LineEnding,
-    LineWidth, QuoteStyle, TrailingCommentSpaceWidth,
+    InlineTableBraceSpaceWidth, InlineTableCommaSpaceWidth, KeyValueEqualsSignSpaceWidth,
+    LineEnding, LineWidth, StringQuoteStyle, TrailingCommentSpaceWidth,
 };
 
 /// # Formatter options
@@ -117,10 +117,13 @@ pub struct FormatOptions {
     /// # The preferred quote character for strings
     ///
     /// **🚧 Deprecated 🚧**\
-    /// Please use `format.rules.quote-style` instead.
-    #[cfg_attr(feature = "jsonschema", schemars(default = "QuoteStyle::default"))]
+    /// Please use `format.rules.string-quote-style` instead.
+    #[cfg_attr(
+        feature = "jsonschema",
+        schemars(default = "StringQuoteStyle::default")
+    )]
     #[cfg_attr(feature = "jsonschema", deprecated)]
-    pub quote_style: Option<QuoteStyle>,
+    pub quote_style: Option<StringQuoteStyle>,
 
     /// # The number of spaces before the trailing comment.
     ///
@@ -169,8 +172,8 @@ pub struct FormatRules {
     ///
     /// In accordance with [RFC 3339](https://datatracker.ietf.org/doc/html/rfc3339), you can use `T` or space character between date and time.
     ///
-    /// - `T`: Example: `2001-01-01T00:00:00`
-    /// - `space`: Example: `2001-01-01 00:00:00`
+    /// - `T`: Use `T` between date and time like `2001-01-01T00:00:00`
+    /// - `space`: Use space between date and time like `2001-01-01 00:00:00`
     /// - `preserve`: Preserve the original delimiter.
     #[cfg_attr(
         feature = "jsonschema",
@@ -194,7 +197,7 @@ pub struct FormatRules {
     /// ```toml
     /// [table]
     ///     [table.sub-table]
-    ///         key = "value"
+    ///     key = "value"
     /// # ^^  <- this
     /// ```
     #[cfg_attr(feature = "jsonschema", schemars(default = "bool::default"))]
@@ -210,6 +213,14 @@ pub struct FormatRules {
     /// # ^^  <- this
     /// ```
     #[cfg_attr(feature = "jsonschema", schemars(default = "bool::default"))]
+    pub indent_table_key_value_pairs: Option<bool>,
+
+    /// # Whether to indent the table key-value pairs
+    ///
+    /// **🚧 Deprecated 🚧**\
+    /// Please use `format.rules.indent-table-key-value-pairs` instead.
+    #[cfg_attr(feature = "jsonschema", schemars(default = "bool::default"))]
+    #[deprecated]
     pub indent_table_key_values: Option<bool>,
 
     /// # The number of spaces per indentation level
@@ -243,9 +254,9 @@ pub struct FormatRules {
     )]
     pub inline_table_comma_space_width: Option<InlineTableCommaSpaceWidth>,
 
-    /// # Whether to align the equal sign in the key-value pairs.
+    /// # Whether to align the equals sign in the key-value pairs.
     ///
-    /// If `true`, the equal sign in the key-value pairs will be aligned.
+    /// If `true`, the equals sign in the key-value pairs will be aligned.
     ///
     /// ⚠️ **WARNING** ⚠️\
     /// This feature does **not** apply to key-value pairs inside single line inline tables.
@@ -262,8 +273,23 @@ pub struct FormatRules {
     /// key3.key4 = "value3"
     /// ```
     #[cfg_attr(feature = "jsonschema", schemars(default = "bool::default"))]
+    pub key_value_equals_sign_alignment: Option<bool>,
+
+    /// # Whether to align the equal sign in the key-value pairs.
+    ///
+    /// **🚧 Deprecated 🚧**\
+    /// Please use `format.rules.key-value-equals-sign-alignment` instead.
+    #[cfg_attr(feature = "jsonschema", schemars(default = "bool::default"))]
+    #[deprecated]
     pub key_value_equal_alignment: Option<bool>,
 
+    /// # The preferred quote character for strings
+    #[cfg_attr(
+        feature = "jsonschema",
+        schemars(default = "StringQuoteStyle::default")
+    )]
+    pub string_quote_style: Option<StringQuoteStyle>,
+
     /// # Whether to align the trailing comments in the key-value pairs.
     ///
     /// If `true`, the trailing comments in value/key-value pairs will be aligned.
@@ -285,7 +311,7 @@ pub struct FormatRules {
     #[cfg_attr(feature = "jsonschema", schemars(default = "bool::default"))]
     pub trailing_comment_alignment: Option<bool>,
 
-    /// # The number of spaces after the equal in a key-value pair.
+    /// # The number of spaces around the equals sign in a key-value pair.
     ///
     /// ```toml
     /// key = "value"
@@ -293,9 +319,20 @@ pub struct FormatRules {
     /// ```
     #[cfg_attr(
         feature = "jsonschema",
-        schemars(default = "KeyValueEqualSpaceWidth::default")
+        schemars(default = "KeyValueEqualsSignSpaceWidth::default")
     )]
-    pub key_value_equal_space_width: Option<KeyValueEqualSpaceWidth>,
+    pub key_value_equals_sign_space_width: Option<KeyValueEqualsSignSpaceWidth>,
+
+    /// # The number of spaces after the equal in a key-value pair.
+    ///
+    /// **🚧 Deprecated 🚧**\
+    /// Please use `format.rules.key-value-equals-sign-space-width` instead.
+    #[cfg_attr(
+        feature = "jsonschema",
+        schemars(default = "KeyValueEqualsSignSpaceWidth::default")
+    )]
+    #[deprecated]
+    pub key_value_equal_space_width: Option<KeyValueEqualsSignSpaceWidth>,
 
     /// # The type of line ending
     ///
@@ -313,8 +350,15 @@ pub struct FormatRules {
     pub line_width: Option<LineWidth>,
 
     /// # The preferred quote character for strings
-    #[cfg_attr(feature = "jsonschema", schemars(default = "QuoteStyle::default"))]
-    pub quote_style: Option<QuoteStyle>,
+    ///
+    /// **🚧 Deprecated 🚧**\
+    /// Please use `format.rules.string-quote-style` instead.
+    #[cfg_attr(
+        feature = "jsonschema",
+        schemars(default = "StringQuoteStyle::default")
+    )]
+    #[deprecated]
+    pub quote_style: Option<StringQuoteStyle>,
 
     /// # The number of spaces before the trailing comment.
     ///
