@@ -6,12 +6,12 @@ mod indent_style;
 mod indent_width;
 mod inline_table_brace_space_width;
 mod inline_table_comma_space_width;
-mod key_value_equal_space_width;
+mod key_value_equals_sign_space_width;
 mod line_ending;
 mod line_width;
 mod one_or_many;
-mod quote_style;
 mod schema_catalog_path;
+mod string_quote_style;
 mod trailing_comment_space_width;
 
 pub use array_bracket_space_width::ArrayBracketSpaceWidth;
@@ -22,12 +22,12 @@ pub use indent_style::IndentStyle;
 pub use indent_width::IndentWidth;
 pub use inline_table_brace_space_width::InlineTableBraceSpaceWidth;
 pub use inline_table_comma_space_width::InlineTableCommaSpaceWidth;
-pub use key_value_equal_space_width::KeyValueEqualSpaceWidth;
+pub use key_value_equals_sign_space_width::KeyValueEqualsSignSpaceWidth;
 pub use line_ending::LineEnding;
 pub use line_width::LineWidth;
 pub use one_or_many::OneOrMany;
-pub use quote_style::QuoteStyle;
 pub use schema_catalog_path::{
     SchemaCatalogPath, JSON_SCHEMASTORE_CATALOG_URL, TOMBI_SCHEMASTORE_CATALOG_URL,
 };
+pub use string_quote_style::StringQuoteStyle;
 pub use trailing_comment_space_width::TrailingCommentSpaceWidth;
