@@ -1,9 +1,11 @@
+use tombi_ast::AstNode;
 use tombi_document_tree::{dig_accessors, TableKind};
-use tombi_extension::{
-    CodeAction, CodeActionKind, DocumentChanges, OneOf, TextDocumentEdit, TextEdit, WorkspaceEdit,
-};
 use tombi_schema_store::{Accessor, AccessorContext, AccessorKeyKind};
-use tower_lsp::lsp_types::OptionalVersionedTextDocumentIdentifier;
+use tombi_text::IntoLsp;
+use tower_lsp::lsp_types::{
+    CodeAction, CodeActionKind, DocumentChanges, OneOf, OptionalVersionedTextDocumentIdentifier,
+    TextDocumentEdit, TextEdit, WorkspaceEdit,
+};
 
 pub enum CodeActionRefactorRewriteName {
     DottedKeysToInlineTable,
@@ -25,6 +27,8 @@ impl std::fmt::Display for CodeActionRefactorRewriteName {
 
 pub fn dot_keys_to_inline_table_code_action(
     text_document_uri: &tombi_uri::Uri,
+    line_index: &tombi_text::LineIndex,
+    _root: &tombi_ast::Root,
     document_tree: &tombi_document_tree::DocumentTree,
     accessors: &[Accessor],
     contexts: &[AccessorContext],
@@ -65,7 +69,8 @@ pub fn dot_keys_to_inline_table_code_action(
                                 range: tombi_text::Range {
                                     start: parent_key_context.range.start,
                                     end: value.range().start,
-                                },
+                                }
+                                .into_lsp(line_index),
                                 new_text: format!(
                                     "{} = {{ {}{}",
                                     parent_key,
@@ -78,7 +83,8 @@ pub fn dot_keys_to_inline_table_code_action(
                                 ),
                             }),
                             OneOf::Left(TextEdit {
-                                range: tombi_text::Range::at(value.symbol_range().end),
+                                range: tombi_text::Range::at(value.symbol_range().end)
+                                    .into_lsp(line_index),
                                 new_text: " }".to_string(),
                             }),
                         ],
@@ -94,6 +100,8 @@ pub fn dot_keys_to_inline_table_code_action(
 
 pub fn inline_table_to_dot_keys_code_action(
     text_document_uri: &tombi_uri::Uri,
+    line_index: &tombi_text::LineIndex,
+    root: &tombi_ast::Root,
     document_tree: &tombi_document_tree::DocumentTree,
     accessors: &[Accessor],
     contexts: &[AccessorContext],
@@ -113,7 +121,23 @@ pub fn inline_table_to_dot_keys_code_action(
             if table.len() == 1
                 && matches!(table.kind(), TableKind::InlineTable { has_comment: false }) =>
         {
-            let (key, value) = table.key_values().iter().next().unwrap();
+            let Some(node) = get_ast_inline_table_node(root, table) else {
+                return None;
+            };
+            if !node.inner_begin_dangling_comments().is_empty()
+                || node
+                    .inner_end_dangling_comments()
+                    .into_iter()
+                    .flatten()
+                    .next()
+                    .is_some()
+                || node.has_inner_comments()
+            {
+                return None;
+            }
+            let Some((key, value)) = table.key_values().iter().next() else {
+                return None;
+            };
 
             Some(CodeAction {
                 title: CodeActionRefactorRewriteName::InlineTableToDottedKeys.to_string(),
@@ -130,14 +154,16 @@ pub fn inline_table_to_dot_keys_code_action(
                                 range: tombi_text::Range::new(
                                     parent_context.range.end,
                                     key.range().start,
-                                ),
+                                )
+                                .into_lsp(line_index),
                                 new_text: ".".to_string(),
                             }),
                             OneOf::Left(TextEdit {
                                 range: tombi_text::Range::new(
                                     value.range().end,
                                     table.symbol_range().end,
-                                ),
+                                )
+                                .into_lsp(line_index),
                                 new_text: "".to_string(),
                             }),
                         ],
@@ -150,3 +176,18 @@ pub fn inline_table_to_dot_keys_code_action(
         _ => None,
     }
 }
+
+fn get_ast_inline_table_node(
+    root: &tombi_ast::Root,
+    table: &tombi_document_tree::Table,
+) -> Option<tombi_ast::InlineTable> {
+    let target_range = table.range();
+    for node in root.syntax().descendants() {
+        if let Some(inline_table) = tombi_ast::InlineTable::cast(node) {
+            if inline_table.range() == target_range {
+                return Some(inline_table);
+            }
+        }
+    }
+    None
+}
