@@ -1,6 +1,5 @@
 use std::path::PathBuf;
 
-use itertools::Either;
 use tombi_config::TomlVersion;
 use tombi_glob::{matches_file_patterns, MatchResult};
 use tower_lsp::lsp_types::TextDocumentIdentifier;
@@ -20,40 +19,24 @@ pub async fn handle_get_status(
 
     let ConfigSchemaStore {
         config,
-        schema_store,
         config_path,
+        ..
     } = backend
         .config_manager
         .config_schema_store_for_uri(&text_document_uri)
         .await;
 
-    let (root, source_schema) = match backend.get_incomplete_ast(&text_document_uri).await {
-        Some(root) => {
-            let source_schema = schema_store
-                .resolve_source_schema_from_ast(&root, Some(Either::Left(&text_document_uri)))
+    let (toml_version, source) = {
+        let document_sources = backend.document_sources.read().await;
+        if let Some(document_source) = document_sources.get(&text_document_uri) {
+            backend
+                .text_document_toml_version_and_source(&text_document_uri, document_source.text())
                 .await
-                .ok()
-                .flatten();
-            (Some(root), source_schema)
+        } else {
+            (TomlVersion::default(), TomlVersionSource::Default)
         }
-        None => (None, None),
     };
 
-    let tombi_document_comment_directive = match root.as_ref() {
-        Some(root) => {
-            tombi_validator::comment_directive::get_tombi_document_comment_directive(root).await
-        }
-        None => None,
-    };
-
-    let (toml_version, source) = backend
-        .source_toml_version(
-            tombi_document_comment_directive,
-            source_schema.as_ref(),
-            &config,
-        )
-        .await;
-
     let mut ignore = None;
     if let Ok(text_document_path) = text_document_uri.to_file_path() {
         ignore = match matches_file_patterns(&text_document_path, config_path.as_deref(), &config) {
