@@ -1,18 +1,19 @@
+use tombi_text::EncodingKind;
 use tower_lsp::lsp_types::{
     ClientCapabilities, ClientInfo, CodeActionProviderCapability, CompletionOptions,
     CompletionOptionsCompletionItem, DeclarationCapability, DiagnosticOptions,
     DiagnosticServerCapabilities, DocumentLinkOptions, FileOperationFilter, FileOperationPattern,
     FileOperationPatternKind, FileOperationRegistrationOptions, FoldingRangeProviderCapability,
     HoverProviderCapability, InitializeParams, InitializeResult, MessageType, OneOf,
-    PositionEncodingKind, SemanticTokensFullOptions, SemanticTokensLegend, SemanticTokensOptions,
-    ServerCapabilities, ServerInfo, TextDocumentSyncCapability, TextDocumentSyncKind,
-    TextDocumentSyncOptions, TextDocumentSyncSaveOptions, TypeDefinitionProviderCapability,
-    WorkDoneProgressOptions, WorkspaceFileOperationsServerCapabilities,
-    WorkspaceFoldersServerCapabilities, WorkspaceServerCapabilities,
+    SemanticTokensFullOptions, SemanticTokensLegend, SemanticTokensOptions, ServerCapabilities,
+    ServerInfo, TextDocumentSyncCapability, TextDocumentSyncKind, TextDocumentSyncOptions,
+    TextDocumentSyncSaveOptions, TypeDefinitionProviderCapability, WorkDoneProgressOptions,
+    WorkspaceFileOperationsServerCapabilities, WorkspaceFoldersServerCapabilities,
+    WorkspaceServerCapabilities,
 };
 
 use crate::{
-    backend::{BackendCapabilities, DiagnosticType},
+    backend::{BackendCapabilities, DiagnosticMode},
     semantic_tokens::SUPPORTED_TOKEN_TYPES,
     Backend,
 };
@@ -49,14 +50,17 @@ pub async fn handle_initialize(
     }
 
     let mut backend_capabilities = backend.capabilities.write().await;
+    backend_capabilities.encoding_kind = negotiated_wide_encoding(&client_capabilities);
     if let Some(text_document_capabilities) = client_capabilities.text_document.as_ref() {
         if let Some(diagnostic_capabilities) = text_document_capabilities.diagnostic.as_ref() {
             if diagnostic_capabilities.dynamic_registration == Some(true) {
-                backend_capabilities.diagnostic_type = DiagnosticType::Pull;
+                backend_capabilities.diagnostic_mode = DiagnosticMode::Pull;
             }
         }
     }
 
+    tracing::debug!("backend_capabilities: {:?}", backend_capabilities);
+
     Ok(InitializeResult {
         server_info: Some(ServerInfo {
             name: String::from("Tombi LSP"),
@@ -105,7 +109,7 @@ pub fn server_capabilities(
     });
 
     ServerCapabilities {
-        position_encoding: Some(PositionEncodingKind::UTF16),
+        position_encoding: Some(backend_capabilities.encoding_kind.into()),
         workspace,
         text_document_sync: Some(TextDocumentSyncCapability::Options(
             TextDocumentSyncOptions {
@@ -165,10 +169,10 @@ pub fn server_capabilities(
             }
             .into(),
         ),
-        diagnostic_provider: if backend_capabilities.diagnostic_type == DiagnosticType::Pull {
+        diagnostic_provider: if backend_capabilities.diagnostic_mode == DiagnosticMode::Pull {
             Some(DiagnosticServerCapabilities::Options(DiagnosticOptions {
                 inter_file_dependencies: false,
-                workspace_diagnostics: true,
+                workspace_diagnostics: false,
                 ..Default::default()
             }))
         } else {
@@ -177,3 +181,17 @@ pub fn server_capabilities(
         ..Default::default()
     }
 }
+
+fn negotiated_wide_encoding(client_capabilities: &ClientCapabilities) -> EncodingKind {
+    client_capabilities
+        .general
+        .as_ref()
+        .and_then(|general| general.position_encodings.as_ref())
+        .and_then(|encodings| {
+            encodings
+                .iter()
+                .filter_map(|encoding| EncodingKind::try_from(encoding).ok())
+                .next()
+        })
+        .unwrap_or_default()
+}
