@@ -127,9 +127,7 @@ where
                             valid_hover_value_contents.insert(hover_value_content.clone());
                         }
                         Err(tombi_validator::Error { diagnostics, .. })
-                            if diagnostics
-                                .iter()
-                                .all(|error| error.level() == tombi_diagnostic::Level::WARNING) =>
+                            if diagnostics.iter().all(|diagnostic| diagnostic.is_warning()) =>
                         {
                             valid_hover_value_contents.insert(hover_value_content.clone());
                         }
