@@ -59,7 +59,7 @@ mod completion_labels {
             #[tokio::test]
             async fn schema_comment_directive_and_comment(
                 r#"
-                #:schema https://json.schemastore.org/tombi.json
+                #:schema https://www.schemastore.org/tombi.json
                 # █
                 "#,
                 Schema(tombi_schema_path()),
@@ -91,7 +91,7 @@ mod completion_labels {
             #[tokio::test]
             async fn tombi_comment_directive_and_colon(
                 r#"
-                #:schema https://json.schemastore.org/tombi.json
+                #:schema https://www.schemastore.org/tombi.json
                 #:█
                 "#,
                 Schema(tombi_schema_path()),
@@ -140,7 +140,7 @@ mod completion_labels {
             #[tokio::test]
             async fn tombi_used_toml_version_with_schema_directive(
                 r#"
-                #:schema https://json.schemastore.org/tombi.json
+                #:schema https://www.schemastore.org/tombi.json
 
                 toml-version = "v1.0.0"
                 █
@@ -264,6 +264,7 @@ mod completion_labels {
                 Schema(tombi_schema_path()),
             ) -> Ok([
                 "files",
+                "format",
                 "lint",
                 "lsp",
                 "schema",
@@ -655,6 +656,8 @@ mod completion_labels {
                 "dynamic",
                 "entry-points",
                 "gui-scripts",
+                "import-names",
+                "import-namespaces",
                 "keywords",
                 "license",
                 "license-files",
@@ -683,6 +686,8 @@ mod completion_labels {
                 "\"description\"",
                 "\"entry-points\"",
                 "\"gui-scripts\"",
+                "\"import-names\"",
+                "\"import-namespaces\"",
                 "\"keywords\"",
                 "\"license\"",
                 "\"license-files\"",
@@ -714,6 +719,8 @@ mod completion_labels {
                 "\"description\"",
                 "\"entry-points\"",
                 "\"gui-scripts\"",
+                "\"import-names\"",
+                "\"import-namespaces\"",
                 "\"keywords\"",
                 "\"license\"",
                 "\"license-files\"",
@@ -838,7 +845,7 @@ mod completion_labels {
                 bindings = "bin"
                 include = [
                     █
-                    { path = "json.schemastore.org/**/*.json", format = "sdist" },
+                    { path = "www.schemastore.org/**/*.json", format = "sdist" },
                 ]
                 "#,
                 Schema(pyproject_schema_path()),
@@ -1270,6 +1277,88 @@ mod completion_labels {
                 "$source_url_or_registry_name"
             ]);
         }
+
+        // Tests for platform specific dependencies (Issue #1192)
+        test_completion_labels! {
+            #[tokio::test]
+            async fn cargo_target_dependencies(
+                r#"
+                [target.'cfg(unix)'.dependencies]
+                █
+                "#,
+                Schema(cargo_schema_path()),
+            ) -> Ok([
+                "$crate_name",
+            ]);
+        }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn cargo_target_dependencies_keys(
+                r#"
+                [target.'cfg(unix)'.dependencies]
+                serde = { █ }
+                "#,
+                Schema(cargo_schema_path()),
+            ) -> Ok([
+                "branch",
+                "default-features",
+                "features",
+                "git",
+                "optional",
+                "package",
+                "path",
+                "registry",
+                "rev",
+                "tag",
+                "version",
+                "workspace",
+            ]);
+        }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn cargo_target_dependencies_tombi_date_time_features_eq_array_with_path(
+                r#"
+                [target.'cfg(unix)'.dependencies]
+                tombi-date-time = { features=[█], path = "crates/tombi-date-time" }
+                "#,
+                Source(project_root_path().join("Cargo.toml")),
+                Schema(cargo_schema_path()),
+            ) -> Ok([
+                "\"default\"",
+                "\"chrono\"",
+                "\"serde\"",
+                "\"\"",
+                "''",
+            ]);
+        }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn cargo_target_dev_dependencies(
+                r#"
+                [target.'cfg(target_os = "linux")'.dev-dependencies]
+                █
+                "#,
+                Schema(cargo_schema_path()),
+            ) -> Ok([
+                "$crate_name",
+            ]);
+        }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn cargo_target_build_dependencies(
+                r#"
+                [target.'cfg(windows)'.build-dependencies]
+                █
+                "#,
+                Schema(cargo_schema_path()),
+            ) -> Ok([
+                "$crate_name",
+            ]);
+        }
     }
 
     mod untagged_union {
