@@ -22,12 +22,12 @@ mod goto_definition_tests {
             #[tokio::test]
             async fn ignores_http_schema_uri(
                 r#"
-                #:schema http://json.schemastore.org/tombi.json█
+                #:schema http://www.schemastore.org/tombi.json█
 
                 toml-version = "v1.0.0"
                 "#,
                 project_root_path().join("tombi.toml"),
-            ) -> Ok(["http://json.schemastore.org/tombi.json"]);
+            ) -> Ok(["http://www.schemastore.org/tombi.json"]);
         );
 
         test_goto_definition!(
@@ -284,6 +284,62 @@ mod goto_definition_tests {
                 project_root_path().join("crates/tombi-glob/Cargo.toml"),
             ) -> Ok([project_root_path().join("crates/tombi-glob/src/bin/profile.rs")]);
         );
+
+        // Tests for platform specific dependencies (Issue #1192)
+        test_goto_definition!(
+            #[tokio::test]
+            async fn target_dependencies_serde_workspace(
+                r#"
+                [target.'cfg(unix)'.dependencies]
+                serde = { workspace█ = true }
+                "#,
+                project_root_path().join("crates/tombi-lsp/Cargo.toml"),
+            ) -> Ok([project_root_path().join("Cargo.toml")]);
+        );
+
+        test_goto_definition!(
+            #[tokio::test]
+            async fn target_dependencies_tombi_ast_workspace(
+                r#"
+                [target.'cfg(unix)'.dependencies]
+                tombi-ast = { workspace█ = true }
+                "#,
+                project_root_path().join("crates/tombi-lsp/Cargo.toml"),
+            ) -> Ok([project_root_path().join("Cargo.toml")]);
+        );
+
+        test_goto_definition!(
+            #[tokio::test]
+            async fn target_dependencies_path(
+                r#"
+                [target.'cfg(unix)'.dependencies]
+                tombi-ast = { path█ = "crates/tombi-ast" }
+                "#,
+                project_root_path().join("Cargo.toml"),
+            ) -> Ok([project_root_path().join("crates/tombi-ast/Cargo.toml")]);
+        );
+
+        test_goto_definition!(
+            #[tokio::test]
+            async fn target_dev_dependencies_workspace(
+                r#"
+                [target.'cfg(target_os = "linux")'.dev-dependencies]
+                serde = { workspace█ = true }
+                "#,
+                project_root_path().join("crates/tombi-lsp/Cargo.toml"),
+            ) -> Ok([project_root_path().join("Cargo.toml")]);
+        );
+
+        test_goto_definition!(
+            #[tokio::test]
+            async fn target_build_dependencies_workspace(
+                r#"
+                [target.'cfg(windows)'.build-dependencies]
+                serde = { workspace█ = true }
+                "#,
+                project_root_path().join("crates/tombi-lsp/Cargo.toml"),
+            ) -> Ok([project_root_path().join("Cargo.toml")]);
+        );
     }
 
     mod pyproject_uv_schema {
@@ -334,6 +390,54 @@ mod goto_definition_tests {
         );
     }
 
+    mod pyproject_uv_workspace_dependencies {
+        use super::*;
+
+        fn pyproject_workspace_fixtures_path() -> std::path::PathBuf {
+            project_root_path().join("crates/tombi-lsp/tests/fixtures/pyproject_workspace")
+        }
+
+        test_goto_definition!(
+            #[tokio::test]
+            async fn project_dependencies_inherit_workspace_version(
+                r#"
+                [project]
+                name = "app"
+                version = "0.1.0"
+                dependencies = [
+                    "pydantic█"
+                ]
+                "#,
+                pyproject_workspace_fixtures_path().join("members/app/pyproject.toml"),
+            ) -> Ok([
+                pyproject_workspace_fixtures_path().join("pyproject.toml")
+            ]);
+        );
+
+        test_goto_definition!(
+            #[tokio::test]
+            async fn workspace_dependencies_list_member_usages(
+                r#"
+                [project]
+                name = "app"
+                version = "0.1.0"
+                dependencies = ["pydantic█"]
+
+                [tool.uv.workspace]
+                members = [
+                    "members/app",
+                    "members/app2",
+                    "members/app3",
+                ]
+                "#,
+                pyproject_workspace_fixtures_path().join("pyproject.toml"),
+            ) -> Ok([
+                pyproject_workspace_fixtures_path().join("members/app/pyproject.toml"),
+                pyproject_workspace_fixtures_path().join("members/app2/pyproject.toml"),
+            ]);
+        );
+    }
+
     mod tombi_schema {
         use super::*;
 
