@@ -3,13 +3,13 @@ use tombi_comment_directive::value::{StringCommonFormatRules, StringCommonLintRu
 use tombi_document_tree::ValueImpl;
 use tombi_future::{BoxFuture, Boxable};
 use tombi_schema_store::ValueSchema;
-use tombi_severity_level::{SeverityLevelDefaultError, SeverityLevelDefaultWarn};
+use tombi_severity_level::SeverityLevelDefaultError;
 use tombi_x_keyword::StringFormat;
 use unicode_segmentation::UnicodeSegmentation;
 
 use crate::{
     comment_directive::get_tombi_key_table_value_rules_and_diagnostics,
-    validate::{format, type_mismatch},
+    validate::{format, push_deprecated_value, type_mismatch},
 };
 
 use super::{validate_all_of, validate_any_of, validate_one_of, Validate};
@@ -325,24 +325,12 @@ async fn validate_string(
     }
 
     if diagnostics.is_empty() && string_schema.deprecated == Some(true) {
-        let level = lint_rules
-            .map(|rules| &rules.common)
-            .and_then(|rules| {
-                rules
-                    .deprecated
-                    .as_ref()
-                    .map(SeverityLevelDefaultWarn::from)
-            })
-            .unwrap_or_default();
-
-        crate::Diagnostic {
-            kind: Box::new(crate::DiagnosticKind::DeprecatedValue(
-                tombi_schema_store::SchemaAccessors::from(accessors),
-                string_value.to_string(),
-            )),
-            range,
-        }
-        .push_diagnostic_with_level(level, &mut diagnostics);
+        push_deprecated_value(
+            &mut diagnostics,
+            accessors,
+            string_value,
+            lint_rules.as_ref().map(|rules| &rules.common),
+        );
     }
 
     if diagnostics.is_empty() {
