@@ -1,9 +1,11 @@
 use tombi_document_tree::{dig_accessors, dig_keys, TableKind};
-use tombi_extension::{
-    CodeAction, CodeActionOrCommand, DocumentChanges, TextDocumentEdit, TextEdit, WorkspaceEdit,
-};
+use tombi_extension::CodeActionOrCommand;
 use tombi_schema_store::{matches_accessors, Accessor, AccessorContext};
-use tower_lsp::lsp_types::{CodeActionKind, OneOf, OptionalVersionedTextDocumentIdentifier};
+use tombi_text::IntoLsp;
+use tower_lsp::lsp_types::{
+    CodeAction, CodeActionKind, DocumentChanges, OneOf, OptionalVersionedTextDocumentIdentifier,
+    TextDocumentEdit, TextEdit, WorkspaceEdit,
+};
 
 use crate::{find_workspace_cargo_toml, get_workspace_path};
 
@@ -119,6 +121,8 @@ impl std::fmt::Display for CodeActionRefactorRewriteName {
 
 pub fn code_action(
     text_document_uri: &tombi_uri::Uri,
+    line_index: &tombi_text::LineIndex,
+    _root: &tombi_ast::Root,
     document_tree: &tombi_document_tree::DocumentTree,
     accessors: &[Accessor],
     contexts: &[AccessorContext],
@@ -136,15 +140,14 @@ pub fn code_action(
     if document_tree.contains_key("workspace") {
         code_actions.extend(code_actions_for_workspace_cargo_toml(
             text_document_uri,
+            line_index,
             document_tree,
-            &cargo_toml_path,
             accessors,
-            contexts,
-            toml_version,
         ))
     } else {
         code_actions.extend(code_actions_for_crate_cargo_toml(
             text_document_uri,
+            line_index,
             document_tree,
             &cargo_toml_path,
             accessors,
@@ -162,18 +165,16 @@ pub fn code_action(
 
 fn code_actions_for_workspace_cargo_toml(
     text_document_uri: &tombi_uri::Uri,
+    line_index: &tombi_text::LineIndex,
     document_tree: &tombi_document_tree::DocumentTree,
-    _cargo_toml_path: &std::path::Path,
     accessors: &[Accessor],
-    contexts: &[AccessorContext],
-    _toml_version: tombi_config::TomlVersion,
 ) -> Vec<CodeActionOrCommand> {
     let mut code_actions = Vec::new();
 
     if let Some(action) =
-        crate_version_code_action(text_document_uri, document_tree, accessors, contexts)
+        crate_version_code_action(text_document_uri, line_index, document_tree, accessors)
     {
-        code_actions.push(CodeActionOrCommand::CodeAction(Box::new(action)));
+        code_actions.push(CodeActionOrCommand::CodeAction(action));
     }
 
     code_actions
@@ -181,68 +182,100 @@ fn code_actions_for_workspace_cargo_toml(
 
 fn code_actions_for_crate_cargo_toml(
     text_document_uri: &tombi_uri::Uri,
-    crate_document_tree: &tombi_document_tree::DocumentTree,
-    crate_cargo_toml_path: &std::path::Path,
+    line_index: &tombi_text::LineIndex,
+    document_tree: &tombi_document_tree::DocumentTree,
+    cargo_toml_path: &std::path::Path,
     accessors: &[Accessor],
     contexts: &[AccessorContext],
     toml_version: tombi_config::TomlVersion,
 ) -> Vec<CodeActionOrCommand> {
     let mut code_actions = Vec::new();
 
-    if let Some((workspace_cargo_toml_path, workspace_document_tree)) = find_workspace_cargo_toml(
-        crate_cargo_toml_path,
-        get_workspace_path(crate_document_tree),
-        toml_version,
-    ) {
+    if let Some((workspace_cargo_toml_path, workspace_root, workspace_document_tree)) =
+        find_workspace_cargo_toml(
+            cargo_toml_path,
+            get_workspace_path(document_tree),
+            toml_version,
+        )
+    {
+        // Load workspace text and create line index for workspace document
+        let Ok(workspace_text) = std::fs::read_to_string(&workspace_cargo_toml_path) else {
+            return code_actions;
+        };
+        let workspace_line_index =
+            tombi_text::LineIndex::new(&workspace_text, line_index.encoding_kind);
+
         // Add workspace-specific code actions here
         if let Some(action) = workspace_code_action(
             text_document_uri,
-            crate_document_tree,
-            &workspace_document_tree,
+            line_index,
+            document_tree,
             accessors,
             contexts,
+            &workspace_document_tree,
         ) {
-            code_actions.push(CodeActionOrCommand::CodeAction(Box::new(action)));
+            code_actions.push(CodeActionOrCommand::CodeAction(action));
         }
 
         if let Some(action) = add_workspace_dependency_code_action(
             text_document_uri,
-            crate_document_tree,
-            &workspace_document_tree,
-            &workspace_cargo_toml_path,
+            line_index,
+            document_tree,
             accessors,
             contexts,
+            &workspace_cargo_toml_path,
+            &workspace_line_index,
+            &workspace_root,
+            &workspace_document_tree,
         ) {
-            code_actions.push(CodeActionOrCommand::CodeAction(Box::new(action)));
+            code_actions.push(CodeActionOrCommand::CodeAction(action));
         }
 
         if let Some(action) = use_workspace_dependency_code_action(
             text_document_uri,
-            crate_document_tree,
-            &workspace_document_tree,
+            line_index,
+            document_tree,
             accessors,
             contexts,
+            &workspace_document_tree,
         ) {
-            code_actions.push(CodeActionOrCommand::CodeAction(Box::new(action)));
+            code_actions.push(CodeActionOrCommand::CodeAction(action));
         }
     }
 
     // Add crate-specific code actions here
     if let Some(action) =
-        crate_version_code_action(text_document_uri, crate_document_tree, accessors, contexts)
+        crate_version_code_action(text_document_uri, line_index, document_tree, accessors)
     {
-        code_actions.push(CodeActionOrCommand::CodeAction(Box::new(action)));
+        code_actions.push(CodeActionOrCommand::CodeAction(action));
     }
 
     code_actions
 }
 
+/// Convert a package field to inherit from workspace configuration.
+///
+/// Before
+///
+/// ```toml
+/// [package]
+/// version = "1.0.0"
+/// ```
+///
+/// After applying "Convert Package Field to Inherit from Workspace"
+///
+/// ```toml
+/// [package]
+/// version.workspace = true
+/// ```
+///
 fn workspace_code_action(
     text_document_uri: &tombi_uri::Uri,
-    crate_document_tree: &tombi_document_tree::DocumentTree,
-    workspace_document_tree: &tombi_document_tree::DocumentTree,
+    line_index: &tombi_text::LineIndex,
+    document_tree: &tombi_document_tree::DocumentTree,
     accessors: &[Accessor],
     contexts: &[AccessorContext],
+    workspace_document_tree: &tombi_document_tree::DocumentTree,
 ) -> Option<CodeAction> {
     if accessors.len() < 2 {
         return None;
@@ -281,7 +314,7 @@ fn workspace_code_action(
         return None;
     }
 
-    let (_, value) = dig_accessors(crate_document_tree, &accessors[..2])?;
+    let (_, value) = dig_accessors(document_tree, &accessors[..2])?;
     dig_keys(
         workspace_document_tree,
         &["workspace", "package", parent_key.as_str()],
@@ -305,7 +338,7 @@ fn workspace_code_action(
                     version: None,
                 },
                 edits: vec![OneOf::Left(TextEdit {
-                    range: parent_key_context.range + value.symbol_range(),
+                    range: (parent_key_context.range + value.symbol_range()).into_lsp(line_index),
                     new_text: format!("{parent_key}.workspace = true"),
                 })],
             }])),
@@ -317,28 +350,37 @@ fn workspace_code_action(
 
 fn use_workspace_dependency_code_action(
     text_document_uri: &tombi_uri::Uri,
+    line_index: &tombi_text::LineIndex,
     crate_document_tree: &tombi_document_tree::DocumentTree,
-    workspace_document_tree: &tombi_document_tree::DocumentTree,
     accessors: &[Accessor],
     contexts: &[AccessorContext],
+    workspace_document_tree: &tombi_document_tree::DocumentTree,
 ) -> Option<CodeAction> {
     if accessors.len() < 2 {
         return None;
     }
 
+    let is_target_dependency = accessors.len() >= 4
+        && (matches_accessors!(accessors[..4], ["target", _, "dependencies", _])
+            || matches_accessors!(accessors[..4], ["target", _, "dev-dependencies", _])
+            || matches_accessors!(accessors[..4], ["target", _, "build-dependencies", _]));
+
     if !(matches_accessors!(accessors[..2], ["dependencies", _])
         || matches_accessors!(accessors[..2], ["dev-dependencies", _])
-        || matches_accessors!(accessors[..2], ["build-dependencies", _]))
+        || matches_accessors!(accessors[..2], ["build-dependencies", _])
+        || is_target_dependency)
     {
         return None; // Not a dependency accessor
     }
 
+    let offset = if is_target_dependency { 2 } else { 0 };
+
     let Some((Accessor::Key(crate_name), value)) =
-        dig_accessors(crate_document_tree, &accessors[..2])
+        dig_accessors(crate_document_tree, &accessors[..2 + offset])
     else {
         return None; // Not a string value
     };
-    let AccessorContext::Key(crate_key_context) = &contexts[1] else {
+    let AccessorContext::Key(crate_key_context) = &contexts[1 + offset] else {
         return None;
     };
 
@@ -363,7 +405,8 @@ fn use_workspace_dependency_code_action(
                             range: tombi_text::Range {
                                 start: crate_key_context.range.start,
                                 end: version.range().end,
-                            },
+                            }
+                            .into_lsp(line_index),
                             // NOTE: Convert to a workspace dependency to make it easier
                             //       to add other settings in the future.
                             new_text: format!("{crate_name} = {{ workspace = true }}"),
@@ -390,12 +433,12 @@ fn use_workspace_dependency_code_action(
 
             let text_edit = if table.kind() == TableKind::KeyValue {
                 TextEdit {
-                    range: crate_key_context.range + version.range(),
+                    range: (crate_key_context.range + version.range()).into_lsp(line_index),
                     new_text: format!("{crate_name} = {{ workspace = true }}"),
                 }
             } else {
                 TextEdit {
-                    range: key.range() + version.range(),
+                    range: (key.range() + version.range()).into_lsp(line_index),
                     new_text: "workspace = true".to_string(),
                 }
             };
@@ -424,16 +467,35 @@ fn use_workspace_dependency_code_action(
     None
 }
 
+/// Convert a dependency version to a table format.
+///
+/// Before
+///
+/// ```toml
+/// [dependencies]
+/// serde = "1.0"
+/// ```
+///
+/// After applying "Convert Dependency to Table Format"
+///
+/// ```toml
+/// [dependencies]
+/// serde = { version = "1.0" }
+/// ```
+///
 fn crate_version_code_action(
     text_document_uri: &tombi_uri::Uri,
+    line_index: &tombi_text::LineIndex,
     document_tree: &tombi_document_tree::DocumentTree,
     accessors: &[Accessor],
-    _contexts: &[AccessorContext],
 ) -> Option<CodeAction> {
     if matches_accessors!(accessors, ["dependencies", _])
         || matches_accessors!(accessors, ["dev-dependencies", _])
         || matches_accessors!(accessors, ["build-dependencies", _])
         || matches_accessors!(accessors, ["workspace", "dependencies", _])
+        || matches_accessors!(accessors, ["target", _, "dependencies", _])
+        || matches_accessors!(accessors, ["target", _, "dev-dependencies", _])
+        || matches_accessors!(accessors, ["target", _, "build-dependencies", _])
     {
         if let Some((_, tombi_document_tree::Value::String(version))) =
             dig_accessors(document_tree, accessors)
@@ -451,11 +513,13 @@ fn crate_version_code_action(
                         },
                         edits: vec![
                             OneOf::Left(TextEdit {
-                                range: tombi_text::Range::at(version.symbol_range().start),
+                                range: tombi_text::Range::at(version.symbol_range().start)
+                                    .into_lsp(line_index),
                                 new_text: "{ version = ".to_string(),
                             }),
                             OneOf::Left(TextEdit {
-                                range: tombi_text::Range::at(version.symbol_range().end),
+                                range: tombi_text::Range::at(version.symbol_range().end)
+                                    .into_lsp(line_index),
                                 new_text: " }".to_string(),
                             }),
                         ],
@@ -483,6 +547,104 @@ fn calculate_insertion_index(existing_crate_names: &[&str], new_crate_name: &str
         .unwrap_or(existing_crate_names.len())
 }
 
+/// Get AST InlineTable from document tree range
+/// First finds the range in document_tree, then locates the corresponding AST node
+fn get_ast_inline_table_from_document_tree(
+    root: &tombi_ast::Root,
+    document_tree: &tombi_document_tree::DocumentTree,
+    keys: &[&str],
+) -> Option<tombi_ast::InlineTable> {
+    use tombi_ast::AstNode;
+
+    // Get the value from document tree to find its range
+    let (_, value) = tombi_document_tree::dig_keys(document_tree, keys)?;
+
+    let tombi_document_tree::Value::Table(doc_table) = value else {
+        return None;
+    };
+
+    // Get the range of the inline table in the document tree
+    let target_range = doc_table.range();
+
+    // Use descendants to find the InlineTable with matching range
+    for node in root.syntax().descendants() {
+        if let Some(inline_table) = tombi_ast::InlineTable::cast(node) {
+            if inline_table.range() == target_range {
+                return Some(inline_table);
+            }
+        }
+    }
+
+    None
+}
+
+/// Calculate insertion position and text for inline table insertion with comma handling
+/// Uses tombi_ast API to properly handle commas and formatting
+fn calculate_inline_table_insertion(
+    ast_inline_table: &tombi_ast::InlineTable,
+    insertion_index: usize,
+    new_entry_text: &str,
+) -> Option<(tombi_text::Position, String)> {
+    use tombi_ast::AstNode;
+
+    let key_values_with_comma: Vec<_> = ast_inline_table.key_values_with_comma().collect();
+
+    if key_values_with_comma.is_empty() {
+        // Empty inline table - insert after opening brace
+        // { } -> { serde = "1.0" }
+        return if let Some(dangling_comment) = ast_inline_table
+            .inner_dangling_comments()
+            .last()
+            .and_then(|comments| comments.last())
+        {
+            Some((
+                dangling_comment.syntax().range().end,
+                format!("\n\n{},\n", new_entry_text),
+            ))
+        } else {
+            Some((
+                ast_inline_table.brace_start()?.range().end,
+                format!("{}", new_entry_text),
+            ))
+        };
+    }
+
+    if insertion_index == 0 {
+        // Insert at the beginning
+        // { tokio = "1.0" } -> { serde = "1.0", tokio = "1.0" }
+        let (first_key_value, _) = key_values_with_comma.first()?;
+        let insert_pos = first_key_value.syntax().range().start;
+        let new_text = format!("{},\n", new_entry_text);
+        return Some((insert_pos, new_text));
+    }
+
+    if insertion_index >= key_values_with_comma.len() {
+        // Insert at the end
+        // { serde = "1.0" } -> { serde = "1.0", tokio = "1.0" }
+        let (last_key_value, last_comma) = key_values_with_comma.last()?;
+        if let Some(last_comma) = last_comma {
+            let insert_pos = last_comma.range().end;
+            let new_text = format!("\n{}, ", new_entry_text);
+            return Some((insert_pos, new_text));
+        } else {
+            let insert_pos = last_key_value.syntax().range().end;
+            let new_text = format!(", {}", new_entry_text);
+            return Some((insert_pos, new_text));
+        }
+    }
+
+    // Insert in the middle
+    // { serde = "1.0", tracing = "0.1" } -> { serde = "1.0", tokio = "1.0", tracing = "0.1" }
+    let (target_key_value, target_comma) = key_values_with_comma.get(insertion_index)?;
+    let insert_pos = if let Some(target_comma) = target_comma {
+        target_comma.range().end
+    } else {
+        target_key_value.syntax().range().end
+    };
+    let new_text = format!("\n{},\n", new_entry_text);
+    Some((insert_pos, new_text))
+}
+
 /// Add a dependency to workspace.dependencies and convert member's dependency
 /// to workspace = true format.
 ///
@@ -490,29 +652,58 @@ fn calculate_insertion_index(existing_crate_names: &[&str], new_crate_name: &str
 /// - The cursor is on a dependency in member Cargo.toml
 /// - The dependency is not yet registered in workspace.dependencies
 /// - The dependency is not already using workspace = true
+///
+/// Before
+///
+/// ```toml
+/// [dependencies]
+/// serde = "1.0"
+/// ```
+///
+/// After applying "Add to Workspace and Inherit Dependency"
+///
+/// ```toml
+/// [workspace.dependencies]
+/// serde = "1.0"
+///
+/// [dependencies]
+/// serde = { workspace = true }
+/// ```
+///
 fn add_workspace_dependency_code_action(
     text_document_uri: &tombi_uri::Uri,
-    crate_document_tree: &tombi_document_tree::DocumentTree,
-    workspace_document_tree: &tombi_document_tree::DocumentTree,
-    workspace_cargo_toml_path: &std::path::Path,
+    line_index: &tombi_text::LineIndex,
+    document_tree: &tombi_document_tree::DocumentTree,
     accessors: &[Accessor],
     contexts: &[AccessorContext],
+    workspace_cargo_toml_path: &std::path::Path,
+    workspace_line_index: &tombi_text::LineIndex,
+    workspace_root: &tombi_ast::Root,
+    workspace_document_tree: &tombi_document_tree::DocumentTree,
 ) -> Option<CodeAction> {
     // Check if accessors match dependency patterns
     if accessors.len() < 2 {
         return None;
     }
 
+    let is_target_dependency = accessors.len() >= 4
+        && (matches_accessors!(accessors[..4], ["target", _, "dependencies", _])
+            || matches_accessors!(accessors[..4], ["target", _, "dev-dependencies", _])
+            || matches_accessors!(accessors[..4], ["target", _, "build-dependencies", _]));
+
     if !(matches_accessors!(accessors[..2], ["dependencies", _])
         || matches_accessors!(accessors[..2], ["dev-dependencies", _])
-        || matches_accessors!(accessors[..2], ["build-dependencies", _]))
+        || matches_accessors!(accessors[..2], ["build-dependencies", _])
+        || is_target_dependency)
     {
         return None;
     }
 
+    let offset = if is_target_dependency { 2 } else { 0 };
+
     // Extract crate name and value from member Cargo.toml
     let Some((Accessor::Key(crate_name), crate_value)) =
-        dig_accessors(crate_document_tree, &accessors[..2])
+        dig_accessors(document_tree, &accessors[..2 + offset])
     else {
         return None;
     };
@@ -544,11 +735,21 @@ fn add_workspace_dependency_code_action(
     };
 
     // Generate workspace edit for workspace.dependencies
-    let workspace_edit =
-        generate_workspace_dependencies_edit(workspace_document_tree, crate_name, crate_value)?;
+    let workspace_edit = generate_workspace_dependencies_edit(
+        workspace_line_index,
+        workspace_root,
+        workspace_document_tree,
+        crate_name,
+        crate_value,
+    )?;
 
     // Generate member edit to convert to workspace = true
-    let member_edit = generate_member_workspace_true_edit(&contexts[1], crate_name, crate_value)?;
+    let member_edit = generate_member_workspace_true_edit(
+        line_index,
+        crate_name,
+        crate_value,
+        &contexts[1 + offset],
+    )?;
 
     // Build WorkspaceEdit with both file changes
     let workspace_edit = WorkspaceEdit {
@@ -583,6 +784,8 @@ fn add_workspace_dependency_code_action(
 
 /// Generate TextEdit for adding dependency to workspace.dependencies
 fn generate_workspace_dependencies_edit(
+    workspace_line_index: &tombi_text::LineIndex,
+    workspace_root: &tombi_ast::Root,
     workspace_document_tree: &tombi_document_tree::DocumentTree,
     crate_name: &str,
     crate_value: &tombi_document_tree::Value,
@@ -590,70 +793,85 @@ fn generate_workspace_dependencies_edit(
     // Get or prepare workspace.dependencies section
     let workspace_deps = dig_keys(workspace_document_tree, &["workspace", "dependencies"]);
 
-    // Extract dependency value to copy to workspace
-    //
-    // NOTE: By convention, dependencies are not written as inline tables,
-    //       so this logic assumes the value is represented as a Table.
-    //
-    let dependency_text = format!("{} = {}\n", crate_name, crate_value.to_string());
+    let Some((_, deps_table)) = workspace_deps else {
+        // NOTE: `workspace.dependencies` section doesn't exist, need to create it
+        //       For now, return None - this will be handled in a future enhancement
+        return None;
+    };
 
-    // Determine insertion position
-    let insertion_range = if let Some((_, deps_table)) = workspace_deps {
-        if let tombi_document_tree::Value::Table(table) = deps_table {
-            // Get existing crate names and calculate insertion index
-            let existing_crates: Vec<&str> = table.keys().map(|key| key.value.as_str()).collect();
-            let insertion_index = calculate_insertion_index(&existing_crates, crate_name);
+    let tombi_document_tree::Value::Table(table) = deps_table else {
+        return None;
+    };
 
-            // Find insertion position in the actual table
-            if insertion_index == 0 {
-                if table.is_empty() {
-                    tombi_text::Range::at(table.range().end)
-                } else {
-                    let range = table.keys().next().unwrap().range();
-                    tombi_text::Range::at(range.start)
-                }
-            } else if insertion_index >= existing_crates.len() {
-                // Insert at the end of the table
+    // Get existing crate names and calculate insertion index
+    let existing_crates: Vec<&str> = table.keys().map(|key| key.value.as_str()).collect();
+    let insertion_index = calculate_insertion_index(&existing_crates, crate_name);
+    let crate_value_text = crate_value.to_string();
+
+    // Find insertion position in the actual table
+    let (insertion_range, new_text) = if table.kind() == TableKind::Table {
+        let insertion_range = if insertion_index == 0 {
+            if table.is_empty() {
+                tombi_text::Range::at(table.range().end)
+            } else {
+                let range = table.keys().next().unwrap().range();
+                tombi_text::Range::at(range.start)
+            }
+        } else if insertion_index >= existing_crates.len() {
+            // Insert at the end of the table
+            let range = table.range();
+            tombi_text::Range::at(range.end)
+        } else {
+            // Insert before the crate at insertion_index
+            if let Some((target_key, _)) = table.get_key_value(existing_crates[insertion_index]) {
+                let range = target_key.range();
+                tombi_text::Range::at(range.start)
+            } else {
                 let range = table.range();
                 tombi_text::Range::at(range.end)
-            } else {
-                // Insert before the crate at insertion_index
-                if let Some((target_key, _)) = table.get_key_value(existing_crates[insertion_index])
-                {
-                    let range = target_key.range();
-                    tombi_text::Range::at(range.start)
-                } else {
-                    let range = table.range();
-                    tombi_text::Range::at(range.end)
-                }
             }
-        } else {
-            return None;
-        }
+        };
+
+        (
+            insertion_range,
+            format!("{crate_name} = {crate_value_text}\n"),
+        )
+    } else if matches!(table.kind(), TableKind::InlineTable { .. }) {
+        // Handle InlineTable case using AST for accurate comma handling
+        let ast_inline_table = get_ast_inline_table_from_document_tree(
+            workspace_root,
+            workspace_document_tree,
+            &["workspace", "dependencies"],
+        )?;
+
+        let new_entry_text = format!("{crate_name} = {crate_value_text}");
+        let (insertion_pos, new_text) =
+            calculate_inline_table_insertion(&ast_inline_table, insertion_index, &new_entry_text)?;
+
+        (tombi_text::Range::at(insertion_pos), new_text)
     } else {
-        // workspace.dependencies section doesn't exist, need to create it
-        // For now, return None - this will be handled in a future enhancement
         return None;
     };
 
     Some(TextEdit {
-        range: insertion_range,
-        new_text: dependency_text,
+        range: insertion_range.into_lsp(workspace_line_index),
+        new_text,
     })
 }
 
 /// Generate TextEdit for converting member dependency to workspace = true
 fn generate_member_workspace_true_edit(
-    accessor_context: &AccessorContext,
+    line_index: &tombi_text::LineIndex,
     crate_name: &str,
     crate_value: &tombi_document_tree::Value,
+    accessor_context: &AccessorContext,
 ) -> Option<TextEdit> {
     let AccessorContext::Key(crate_key_context) = accessor_context else {
         return None;
     };
 
     Some(TextEdit {
-        range: crate_key_context.range + crate_value.range(),
+        range: (crate_key_context.range + crate_value.range()).into_lsp(line_index),
         new_text: format!("{} = {{ workspace = true }}", crate_name),
     })
 }
