@@ -162,6 +162,9 @@ async fn completion_member(
     if matches_accessors!(accessors, ["dependencies", _, "version"])
         || matches_accessors!(accessors, ["dev-dependencies", _, "version"])
         || matches_accessors!(accessors, ["build-dependencies", _, "version"])
+        || matches_accessors!(accessors, ["target", _, "dependencies", _, "version"])
+        || matches_accessors!(accessors, ["target", _, "dev-dependencies", _, "version"])
+        || matches_accessors!(accessors, ["target", _, "build-dependencies", _, "version"])
     {
         if let Some(Accessor::Key(c_name)) = accessors.get(accessors.len() - 2) {
             return complete_crate_version(
@@ -176,6 +179,9 @@ async fn completion_member(
     } else if matches_accessors!(accessors, ["dependencies", _])
         || matches_accessors!(accessors, ["dev-dependencies", _])
         || matches_accessors!(accessors, ["build-dependencies", _])
+        || matches_accessors!(accessors, ["target", _, "dependencies", _])
+        || matches_accessors!(accessors, ["target", _, "dev-dependencies", _])
+        || matches_accessors!(accessors, ["target", _, "build-dependencies", _])
     {
         if let Some(Accessor::Key(c_name)) = accessors.last() {
             return complete_crate_version(
@@ -192,9 +198,27 @@ async fn completion_member(
         || matches_accessors!(accessors, ["build-dependencies", _, "features", _])
         || matches_accessors!(accessors, ["dependencies", _, "features"])
         || matches_accessors!(accessors, ["dev-dependencies", _, "features"])
-        || matches_accessors!(accessors, ["build-dependencies", _, "features"]))
+        || matches_accessors!(accessors, ["build-dependencies", _, "features"])
+        || matches_accessors!(accessors, ["target", _, "dependencies", _, "features", _])
+        || matches_accessors!(
+            accessors,
+            ["target", _, "dev-dependencies", _, "features", _]
+        )
+        || matches_accessors!(
+            accessors,
+            ["target", _, "build-dependencies", _, "features", _]
+        )
+        || matches_accessors!(accessors, ["target", _, "dependencies", _, "features"])
+        || matches_accessors!(accessors, ["target", _, "dev-dependencies", _, "features"])
+        || matches_accessors!(
+            accessors,
+            ["target", _, "build-dependencies", _, "features"]
+        ))
     {
-        if let Some(Accessor::Key(crate_name)) = accessors.get(1) {
+        let is_target_dependency = accessors.first().map(|a| a.as_key()) == Some(Some("target"));
+        let offset = if is_target_dependency { 2 } else { 0 };
+
+        if let Some(Accessor::Key(crate_name)) = accessors.get(1 + offset) {
             if let Some((_, tombi_document_tree::Value::Incomplete { .. })) =
                 dig_accessors(document_tree, accessors)
             {
@@ -205,10 +229,10 @@ async fn completion_member(
                 crate_name.as_str(),
                 document_tree,
                 cargo_toml_path,
-                &accessors[..3],
+                &accessors[..3 + offset],
                 position,
                 toml_version,
-                accessors.get(3).and_then(|_| {
+                accessors.get(3 + offset).and_then(|_| {
                     dig_accessors(document_tree, accessors).and_then(|(_, feature)| {
                         if let tombi_document_tree::Value::String(feature_string) = feature {
                             Some(feature_string)
@@ -324,7 +348,7 @@ fn complete_crate_feature<'a: 'b, 'b>(
                 .collect_vec(),
         ) {
             if boolean.value() {
-                let Some((workspace_cargo_toml_path, workspace_document_tree)) =
+                let Some((workspace_cargo_toml_path, _, workspace_document_tree)) =
                     find_workspace_cargo_toml(
                         cargo_toml_path,
                         get_workspace_path(document_tree),
@@ -480,7 +504,7 @@ async fn fetch_local_crate_features(
     toml_version: TomlVersion,
 ) -> Option<AHashMap<String, Vec<String>>> {
     // Get the directory of the current Cargo.toml file
-    let (_, subcrate_document_tree) = find_path_crate_cargo_toml(
+    let (_, _, subcrate_document_tree) = find_path_crate_cargo_toml(
         cargo_toml_path,
         std::path::Path::new(sub_crate_path),
         toml_version,
